==> freemedforms-project_0.7.1.orig.tar.gz: freemedforms-0.7.1/global_resources/translations/fdmainwindowplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>MainWin::Internal::MainWindow</name>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="115"/>
        <source>DOB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="107"/>
        <source>Patient information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="128"/>
        <source>yyyy/MM/dd</source>
        <comment>Format de date</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="135"/>
        <source>Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="156"/>
        <source>Kg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="161"/>
        <source>lbs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="190"/>
        <source>cm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="195"/>
        <source>m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="200"/>
        <source>inches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="208"/>
        <source>Gender</source>
        <translation>Geschlecht</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="169"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="20"/>
        <source>Patient Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="27"/>
        <source>Family or occidental last names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="34"/>
        <source>Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="41"/>
        <source>Given names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="222"/>
        <source>Creatinine clearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="243"/>
        <source>mL/min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="248"/>
        <source>mL/sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="256"/>
        <source>Creatinine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="277"/>
        <source>mg/L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="282"/>
        <source>mg/dL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="287"/>
        <source>mmol/L</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="292"/>
        <source>µmol/L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="304"/>
        <source>Drugs precautions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWin::MainWindow</name>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="263"/>
        <source>Creating Main Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="359"/>
        <source>Transmitting posologies...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="385"/>
        <source>Connected to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="400"/>
        <source>Initializing drugs database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="406"/>
        <source>Entering selection mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="415"/>
        <source>Reading exchange file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="749"/>
        <source>Save actual prescription ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="750"/>
        <source>The actual prescription is not empty. Do you want to save it before creating a new one ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="854"/>
        <source>Opening a prescription : merge or replace ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="855"/>
        <source>There is a prescription inside editor, do you to replace it or to add the opened prescription ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="856"/>
        <source>Replace prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="856"/>
        <source>Add to prescription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="857"/>
        <source>Open a prescription</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="241"/>
        <source>Preparing dosage transmission</source>
        <translation>Bereite Dosis Transmission vor</translation>
    </message>
</context>
<context>
    <name>diMedinTux</name>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="92"/>
        <source>Automatic configuration for MedinTux usage</source>
        <translation>Automatische konfiguration für MedinTux</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="93"/>
        <source>This assistant will create a new entrie into the users&apos; menu of DrTux.
You can create a new prescription by clicking this menu.
Please take care that if DrTux&apos; location changes, or if FreeDiams&apos; location changes, you must reconfigure DrTux with this assitant.</source>
        <translation>Der Assistent wird ein neuen Eintrag im Anwendermenü von DrTux anlegen.
Sie können ein neues Rezept durch anklicken des Menüs erstellen.
Bitte achten sie auf die lokalen Änderungen von DrTux oder FreeDiams.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="98"/>
        <source>This assistant will try to find your MedinTux path. If it doesn&apos;t, you will be asked about this place. Then it will configure a new user&apos;s menu for DrTux and create a new list in your prescription&apos;s default list.
Please refer to the documentation.</source>
        <translation>Der assistent wird versuchen MedinTux zu finden. Wenn er nichts findet werden sie gefragt werden.Dann werden anpassungen in DrTux gemacht.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="113"/>
        <source>Please select Manager&apos;s binary path</source>
        <translation>Bitte wählen sie den Managers Pfad</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="117"/>
        <source>Unable to find Manager binary path.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="126"/>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="128"/>
        <source>Unable to configure MedinTux : Resources path does not exists. Path to DrTux binary : %1</source>
        <translation>Kann MedinTux nicht konfigurieren Resources Pfad existiert nicht. Pfad zu DrTux binary %1</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="132"/>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="134"/>
        <source>Unable to configure MedinTux : Menus path does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation>Kann MedinTux nicht konfigurieren. Menüpfad existiert nicht und kann nichr angelegt werden. Pfad zu Dr.Tux binary %1</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="145"/>
        <source>Can not deleted old DrugsInteractions menu entry %1</source>
        <translation>Kann nicht alten DrugsInteraktions Menüeintrag löschen %1</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="152"/>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="154"/>
        <source>Unable to configure MedinTux: FreeDiams menu does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="181"/>
        <source>Unable to configure MedinTux user menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="184"/>
        <source>MedinTux user&apos;s menu correctly updated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="197"/>
        <source>Select path to the Prescription Menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="199"/>
        <source>Can not find menu list directory. Asking user.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="204"/>
        <source>Using %1 as prescription menu directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="219"/>
        <source>Prescription menu correctly updated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="228"/>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="230"/>
        <source>Unable to find the prescription list directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="236"/>
        <source>MedinTux cache has been correctly cleared.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="238"/>
        <source>Unable to clear the MedinTux cache.
You have to do this by hand.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="243"/>
        <source>DrTux is now fully configured for %1.</source>
        <translation>DrTux ist nun voll konfiguriert für %1.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="244"/>
        <source>You can run %1 using DrTux User&apos;s Menu.</source>
        <translation>Sie können %1 mit DrTux User&apos;s Menü benutzen.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="245"/>
        <source>If you encounter difficulties with DrTux integration, please refer to documentation of both applications.
%1</source>
        <translation>Wenn Schwierigkeiten bei der Dr Tux Intergration auftauchen, lesen sie die Bedienungsanleitung beider Applikationen
%1</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="247"/>
        <source>DrTux is not correctly configured.</source>
        <translation>Dr Tux ist nicht korrekt konfiguriert.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="248"/>
        <source>This assitant encountered errors during its process.</source>
        <translation>Der Assistent hatte Probleme während seines Prozesses.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="249"/>
        <source>This is the log of the processes 
%1</source>
        <translation>Dies ist der Log der Prozesse
%1</translation>
    </message>
</context>
<context>
    <name>diMedintux</name>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="51"/>
        <source>Prescribe with FreeDiams</source>
        <translation>Verschreiben mit FreeDiams</translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.7.4.orig.tar.gz: freemedforms-0.7.4/global_resources/translations/fdmainwindowplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>MainWin::Internal::MainWindow</name>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="115"/>
        <source>DOB</source>
        <translation>GebDat.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="107"/>
        <source>Patient information</source>
        <translation>Patienteninformation</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="20"/>
        <source>Patient name</source>
        <translation>Patientenname</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="128"/>
        <source>yyyy/MM/dd</source>
        <comment>Format de date</comment>
        <translation>dd.MM.yyyy</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="135"/>
        <source>Weight</source>
        <translation>Gewicht</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="208"/>
        <source>Gender</source>
        <translation>Geschlecht</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="169"/>
        <source>Height</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="27"/>
        <source>Family or occidental last names</source>
        <translation>Familienname</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="34"/>
        <source>Firstname</source>
        <translation>Vorname</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="41"/>
        <source>Given names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="222"/>
        <source>Creatinine clearance</source>
        <translation>Kreatinin-Clearance</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="256"/>
        <source>Creatinine</source>
        <translation>Kreatinin</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.ui" line="304"/>
        <source>Drugs precautions</source>
        <translation>Medikamentenwarnungen</translation>
    </message>
</context>
<context>
    <name>MainWin::MainWindow</name>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="263"/>
        <source>Creating Main Window</source>
        <translation>Erzeuge Hauptfenster</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="359"/>
        <source>Transmitting posologies...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="385"/>
        <source>Connected to %1</source>
        <translation>Verbunden zu %1</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="400"/>
        <source>Initializing drugs database</source>
        <translation>Initialisiere Medikamentendatenbank</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="406"/>
        <source>Entering selection mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="415"/>
        <source>Reading exchange file...</source>
        <translatorcomment>bad translation</translatorcomment>
        <translation>Lese Austausch-Datei</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="749"/>
        <source>Save actual prescription?</source>
        <translation>Aktuelle Verschreibung speichern?</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="750"/>
        <source>The actual prescription is not empty. Do you want to save it before creating a new one?</source>
        <translation>Die aktuelle Verschreibung ist nicht leer. Wollen Sie sie speichern, bevor eine neue erstellt wird?</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="854"/>
        <source>Opening a prescription : merge or replace?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="855"/>
        <source>There is a prescription inside editor, do you to replace it or to add the opened prescription?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="856"/>
        <source>Replace prescription</source>
        <translation>Verschreibung ersetzen</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="856"/>
        <source>Add to prescription</source>
        <translation>Zu Verschreibung hinzufügen</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="857"/>
        <source>Open a prescription</source>
        <translation>Eine Verschreibung öffnen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/mainwindow.cpp" line="241"/>
        <source>Preparing dosage transmission</source>
        <translation>Bereite Dosis Transmission vor</translation>
    </message>
</context>
<context>
    <name>diMedinTux</name>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="92"/>
        <source>Automatic configuration for MedinTux usage</source>
        <translation>Automatische konfiguration für MedinTux</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="98"/>
        <source>This assistant will try to find your MedinTux path. If it doesn&apos;t, you will be asked about this place. Then it will configure a new user&apos;s menu for DrTux and create a new list in your prescription&apos;s default list.
Please refer to the documentation.</source>
        <translation>Der assistent wird versuchen MedinTux zu finden. Wenn er nichts findet werden sie gefragt werden.Dann werden anpassungen in DrTux gemacht.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="113"/>
        <source>Please select Manager&apos;s binary path</source>
        <translation>Bitte wählen sie den Managers Pfad</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="117"/>
        <source>Unable to find Manager binary path.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="126"/>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="128"/>
        <source>Unable to configure MedinTux : Resources path does not exists. Path to DrTux binary : %1</source>
        <translation>Kann MedinTux nicht konfigurieren Resources Pfad existiert nicht. Pfad zu DrTux binary %1</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="132"/>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="134"/>
        <source>Unable to configure MedinTux : Menus path does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation>Kann MedinTux nicht konfigurieren. Menüpfad existiert nicht und kann nichr angelegt werden. Pfad zu Dr.Tux binary %1</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="145"/>
        <source>Can not deleted old DrugsInteractions menu entry %1</source>
        <translation>Kann nicht alten DrugsInteraktions Menüeintrag löschen %1</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="152"/>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="154"/>
        <source>Unable to configure MedinTux: FreeDiams menu does not exists and can not be created. Path to DrTux binary : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="181"/>
        <source>Unable to configure MedinTux user menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="184"/>
        <source>MedinTux user&apos;s menu correctly updated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="197"/>
        <source>Select path to the Prescription Menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="199"/>
        <source>Can not find menu list directory. Asking user.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="204"/>
        <source>Using %1 as prescription menu directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="219"/>
        <source>Prescription menu correctly updated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="228"/>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="230"/>
        <source>Unable to find the prescription list directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="236"/>
        <source>MedinTux cache has been correctly cleared.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="238"/>
        <source>Unable to clear the MedinTux cache.
You have to do this by hand.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="243"/>
        <source>DrTux is now fully configured for %1.</source>
        <translation>DrTux ist nun voll konfiguriert für %1.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="244"/>
        <source>You can run %1 using DrTux&apos; user menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="248"/>
        <source>This assistant encountered errors during its process.</source>
        <translation>Während der Ausführung dieses Assistenten traten Fehler auf.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="245"/>
        <source>If you encounter difficulties with DrTux integration, please refer to documentation of both applications.
%1</source>
        <translation>Wenn Schwierigkeiten bei der DrTux-Intergration auftauchen, lesen sie die Bedienungsanleitung beider Applikationen
%1</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="93"/>
        <source>This assistant will create a new entry into the users&apos; menu of DrTux.
You can create a new prescription by clicking this menu.
Please take care that if DrTux&apos; location changes, or if FreeDiams&apos; location changes, you must reconfigure DrTux with this assistant.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="247"/>
        <source>DrTux is not correctly configured.</source>
        <translation>DrTux ist nicht korrekt konfiguriert.</translation>
    </message>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="249"/>
        <source>This is the log of the processes 
%1</source>
        <translation>Dies ist der Log der Prozesse
%1</translation>
    </message>
</context>
<context>
    <name>diMedintux</name>
    <message>
        <location filename="../../freediams/plugins/mainwindowplugin/medintux.cpp" line="51"/>
        <source>Prescribe with FreeDiams</source>
        <translation>Verschreiben mit FreeDiams</translation>
    </message>
</context>
</TS>
